/*
 * SPDX-FileCopyrightText: 2015 Kevin Ottens <ervin@kde.org>
 * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */


#ifndef ZANSHIN_TESTLIB_TESTHELPERS_H
#define ZANSHIN_TESTLIB_TESTHELPERS_H

namespace Testlib {

namespace TestHelpers
{
    void waitForEmptyJobQueue();
}

}

#endif
