/*
 * SPDX-FileCopyrightText: 2011-2014 Kevin Ottens <ervin@kde.org>
 * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */


#ifndef APP_ABOUTDATA_H
#define APP_ABOUTDATA_H

#include <KAboutData>

namespace App
{
    KAboutData getAboutData();
}

#endif

