/*
 * SPDX-FileCopyrightText: 2008 Trevor Pounds
 * SPDX-License-Identifier: MIT
 */

#ifndef __MOCKITOPP_HPP__
#define __MOCKITOPP_HPP__

#include "exceptions.hpp"
#include "matchers.hpp"
#include "mock_object.hpp"

#endif //__MOCKITOPP_HPP__
