/*
 * SPDX-FileCopyrightText: 2016 Kevin Ottens <ervin@kde.org>
 * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */


#ifndef QTEST_GUI_ZANSHIN_H
#define QTEST_GUI_ZANSHIN_H

#include <testlib/qtest_zanshin.h>

#endif // QTEST_GUI_ZANSHIN_H
